pub struct Sigma1Proof<G1, G2, F> {
pub a1: G2,
pub a2: G1,
pub z1: F,
pub z2: F,
pub z3: F,
}Expand description
Σ-protocol 1: proves E2 and y_com commit to the same y.
Fields
a1: G2a2: G1z1: Fz2: Fz3: FTrait Implementations
Sourceimpl CanonicalDeserialize for Sigma1Proof<ArkG1, ArkG2, ArkFr>
impl CanonicalDeserialize for Sigma1Proof<ArkG1, ArkG2, ArkFr>
Sourcefn deserialize_with_mode<R: Read>(
r: R,
c: Compress,
v: Validate,
) -> Result<Self, SerializationError>
fn deserialize_with_mode<R: Read>( r: R, c: Compress, v: Validate, ) -> Result<Self, SerializationError>
The general deserialize method that takes in customization flags.
fn deserialize_compressed<R>(reader: R) -> Result<Self, SerializationError>where
R: Read,
fn deserialize_compressed_unchecked<R>(
reader: R,
) -> Result<Self, SerializationError>where
R: Read,
fn deserialize_uncompressed<R>(reader: R) -> Result<Self, SerializationError>where
R: Read,
fn deserialize_uncompressed_unchecked<R>(
reader: R,
) -> Result<Self, SerializationError>where
R: Read,
Sourceimpl CanonicalSerialize for Sigma1Proof<ArkG1, ArkG2, ArkFr>
impl CanonicalSerialize for Sigma1Proof<ArkG1, ArkG2, ArkFr>
Sourcefn serialize_with_mode<W: Write>(
&self,
w: W,
c: Compress,
) -> Result<(), SerializationError>
fn serialize_with_mode<W: Write>( &self, w: W, c: Compress, ) -> Result<(), SerializationError>
The general serialize method that takes in customization flags.
fn serialized_size(&self, c: Compress) -> usize
fn serialize_compressed<W>(&self, writer: W) -> Result<(), SerializationError>where
W: Write,
fn compressed_size(&self) -> usize
fn serialize_uncompressed<W>(&self, writer: W) -> Result<(), SerializationError>where
W: Write,
fn uncompressed_size(&self) -> usize
Sourceimpl<G1: Clone, G2: Clone, F: Clone> Clone for Sigma1Proof<G1, G2, F>
impl<G1: Clone, G2: Clone, F: Clone> Clone for Sigma1Proof<G1, G2, F>
Sourcefn clone(&self) -> Sigma1Proof<G1, G2, F>
fn clone(&self) -> Sigma1Proof<G1, G2, F>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Valid for Sigma1Proof<ArkG1, ArkG2, ArkFr>
impl Valid for Sigma1Proof<ArkG1, ArkG2, ArkFr>
fn check(&self) -> Result<(), SerializationError>
fn batch_check<'a>(
batch: impl Iterator<Item = &'a Self> + Send,
) -> Result<(), SerializationError>where
Self: 'a,
impl<G1, G2, F> StructuralPartialEq for Sigma1Proof<G1, G2, F>